@@ -13,6 +13,6 @@ void smb_auth_fn(
 		char		*user,   int userlen,
 		char		*passwd, int passwdlen);
 
-void DeleteOldSmbAuthData(time_t ctime);
+void DeleteOldSmbAuthData(time_t change_time);
 
 #endif	/* __AUTH_H__ */
