@@ -257,11 +257,11 @@ int KDEworkaround(const char *path){
 }
 
 BUFFER* GetSmbStateBuffer(struct fuse_file_info *fi){
-    return *((BUFFER**)(&fi->fh));
+    return *((BUFFER**)(void*)(&fi->fh));
 }
 
 void StoreSmbStateBuffer(struct fuse_file_info *fi, BUFFER *buf){
-    *((BUFFER**)(&fi->fh)) = buf;
+    *((BUFFER**)(void*)(&fi->fh)) = buf;
 }
 
 SmbState* GetSmbState(struct fuse_file_info *fi){
