@@ -23,7 +23,7 @@
 typedef struct{
     char	reserved[sizeof(LIST)];
     int		ref_count;	// the number of item references
-    time_t	ctime;		// item creation time
+    time_t	change_time;	// item modification time
     int		type;		// item type: comp/link/group
     hstring	name;		// pointer to item name and its hash
     hstring	link;		// pointer to link and its hash
@@ -46,7 +46,7 @@ int  getdir(ARRAY *array, const char *path, int flag);
 void DeleteSmbItemArray(ARRAY *array);
 void RequestSmbItem(smbitem *item);
 void ReleaseSmbItem(smbitem* item);
-void DeleteOldSmbItem(time_t ctime, int flag);
+void DeleteOldSmbItem(time_t change_time, int flag);
 void UpdateSambaTree();
 
 int  GetPathType(const char *path, BUFFER *buf);
